@@ -1,13 +1,25 @@
-#ifndef GNOME_RADIO_INFO_H
-#define GNOME_RADIO_INFO_H 1
+#ifndef GNOME_RADIO_FILE_H
+#define GNOME_RADIO_FILE_H 1
 
 #include <glib.h>
 #include <gtk/gtk.h>
+#include <gst/player/player.h>
 
 typedef struct _LocationInfo LocationInfo;
 typedef struct _RadioInfo RadioInfo;
 typedef struct _StreamInfo StreamInfo;
 typedef struct _RadioWindow RadioWindow;
+typedef struct _RadioOscilloscope RadioOscilloscope;
+
+struct _RadioOscilloscope {
+	GtkWidget *window;
+        struct timeval *tv;
+        struct timezone *tz;
+        GstPlayer *player;
+	gchar *window_title;
+	gchar *text;
+	gchar *uri;
+};
 
 struct _RadioWindow {
 	GtkWidget *window;
@@ -36,4 +48,4 @@ struct _StreamInfo {
 	StreamInfo *prev;	
 };
 
-#endif /* GNOME_RADIO_INFO_H */
+#endif /* GNOME_RADIO_FILE_H */
